import React from 'react';
import { PageContainer } from '@ant-design/pro-components';
import { Button, Row, Col, Card } from 'antd';
import useBool from '@/utils/hooks/useBool';
import { downloadPackage } from '@/services/package';
import List from './List';
import DishList from './DishList';

import './style.less';

export default (props) => {
  const [current, setCurrent] = React.useState({});
  const pkgRef = React.useRef();
  const dishRef = React.useRef();
  const [exporting, startExport, stopExport] = useBool();

  const onAdd = () => pkgRef.current.new();
  const onDishAdd = () => dishRef.current.new();

  const onExport = () => {
    startExport();
    downloadPackage().then(stopExport).catch(stopExport);
  }

  return (
    <Row gutter={24}>
      <Col span={12}>
        <Card title="套餐列表" extra={(
          <>
            <Button type='primary' onClick={onAdd}>新增</Button>
            <Button onClick={onExport} loading={exporting}>导出</Button>
          </>
        )}>
          <List ref={pkgRef} current={current} setCurrent={setCurrent}/>
        </Card>
      </Col>
      <Col span={12}>
        <Card title={`${current.name || '套餐'} 明细`} extra={<Button onClick={onDishAdd}>新增</Button>}>
          <DishList current={current} ref={dishRef} />
        </Card>
      </Col>
    </Row>
  )
}
